@@ -59,8 +59,13 @@ class FileOrDir(click.ParamType):
 @click.command()
 @click.version_option(version="", message=version.version_info())
 @click.option("--config-file", default=None)
+@click.option("--ignore-init-modules", is_flag=True, help="Ignore __init__.py files.")
 @click.argument("files", type=FileOrDir(), nargs=-1)
-def cli(files: NestedSequence, config_file: Optional[str] = None) -> None:
+def cli(
+    files: NestedSequence,
+    config_file: Optional[str] = None,
+    ignore_init_modules: bool = False,
+) -> None:
     """Corrects the source code of the specified files."""
     # Compose configuration
     config_files: List[str] = []
@@ -80,6 +85,11 @@ def cli(files: NestedSequence, config_file: Optional[str] = None) -> None:
 
     # Process inputs
     flattened_files = flatten(files)
+    if ignore_init_modules:
+        flattened_files = tuple(
+            file for file in flattened_files if "__init__.py" not in file.name
+        )
+
     try:
         fixed_code = services.fix_files(flattened_files, config)
     except FileNotFoundError as error:
