@@ -32,7 +32,6 @@ common_statements: Dict[str, str] = {
     "patch": "from unittest.mock import patch",
     "StringIO": "from io import StringIO",
     "suppress": "from contextlib import suppress",
-    "TempdirFactory": "from _pytest.tmpdir import TempdirFactory",
     "tz": "from dateutil import tz",
     "YAMLError": "from yaml import YAMLError",
 }
@@ -466,37 +465,40 @@ class SourceCode:  # noqa: R090
                 # Format is required until there is no more need of the
                 # experimental-string-processing flag of the Black formatter.
                 match = re.match(
-                    fr"(?P<from>from {package_name} import) (?P<imports>.*)",
+                    fr"(?P<from>from {package_name} import) "
+                    fr"(?P<imports>[^#]*)(?P<comment>#.*)?",
                     line,
                 )
                 # fmt: on
                 if match is not None:
                     line_number = self.imports.index(line)
-                    imports = match["imports"].split(", ")
+                    imports = [
+                        import_.strip() for import_ in match["imports"].split(", ")
+                    ]
                     imports.remove(object_name)
                     new_imports = ", ".join(imports)
+                    if match["comment"]:
+                        new_imports += f'  {match["comment"]}'
                     self.imports[line_number] = f"{match['from']} {new_imports}"
                     return
             # If it's a multiline import statement
-            # fmt: off
-            # Format is required until there is no more need of the
-            # experimental-string-processing flag of the Black formatter.
             elif re.match(
-                fr"from {package_name} import .*?\($",
+                rf"from {package_name} import .*?\($",
                 line,
             ):
-                # fmt: on
                 line_number = self.imports.index(line)
                 # Remove the object name from the multiline imports
                 while line_number + 1 < len(self.imports):
                     line_number += 1
-                    if re.match(fr"\s*?{object_name},?", self.imports[line_number]):
+                    if re.match(rf"\s*?{object_name},?", self.imports[line_number]):
                         self.imports.pop(line_number)
                         break
 
                 # Remove the whole import if there is no other object loaded
-                if re.match(r"\s*from .* import", self.imports[line_number - 1]) \
-                        and self.imports[line_number] == ')':
+                if (
+                    re.match(r"\s*from .* import", self.imports[line_number - 1])
+                    and self.imports[line_number] == ")"
+                ):
                     self.imports.pop(line_number)
                     self.imports.pop(line_number - 1)
 
